@@ -57,6 +57,13 @@ struct _OsinfoLoaderPrivate
     OsinfoDb *db;
 };
 
+struct _OsinfoEntityKey
+{
+    const char *name;
+    GType type;
+};
+typedef struct _OsinfoEntityKey OsinfoEntityKey;
+
 static void
 osinfo_loader_finalize (GObject *object)
 {
@@ -179,6 +186,48 @@ osinfo_loader_string(const char *xpath,
     return ret;
 }
 
+static gboolean
+osinfo_loader_boolean(const char *xpath,
+                      xmlXPathContextPtr ctxt,
+                      GError **err)
+{
+
+    xmlNodePtr *nodes;
+    int count;
+    int i;
+    gboolean ret = FALSE;
+
+    g_return_val_if_fail(ctxt != NULL, FALSE);
+    g_return_val_if_fail(xpath != NULL, FALSE);
+
+    count = osinfo_loader_nodeset(xpath, ctxt, &nodes, err);
+
+    if (count < 0) {
+        return FALSE;
+    }
+    for (i = 0 ; i < count ; i++) {
+        xmlNodePtr node = nodes[i];
+
+        if (!node->children) {
+            /* node is present -> TRUE */
+            ret = TRUE;
+            break;
+        }
+        if (node->children->type != XML_TEXT_NODE) {
+            OSINFO_ERROR(err, _("Expected a text node attribute value"));
+            goto cleanup;
+        }
+
+        if (g_strcmp0((const char *)nodes[i]->children->content, "true") == 0) {
+            ret = TRUE;
+            break;
+        }
+    }
+cleanup:
+    g_free(nodes);
+    return ret;
+}
+
 static gchar *
 osinfo_loader_doc(const char *xpath,
                   xmlXPathContextPtr ctxt,
@@ -220,7 +269,7 @@ osinfo_loader_doc(const char *xpath,
 
 static void osinfo_loader_entity(OsinfoLoader *loader,
                                  OsinfoEntity *entity,
-                                 const gchar *const *keys,
+                                 const OsinfoEntityKey *keys,
                                  xmlXPathContextPtr ctxt,
                                  xmlNodePtr root,
                                  GError **err)
@@ -229,37 +278,63 @@ static void osinfo_loader_entity(OsinfoLoader *loader,
     const gchar * const *langs = g_get_language_names ();
 
     /* Standard well-known keys first, allow single value only */
-    for (i = 0 ; keys[i] != NULL; i++) {
-        gchar *value = NULL;
-        gchar *xpath;
+    for (i = 0 ; keys != NULL && keys[i].name != NULL; i++) {
+        gchar *value_str = NULL;
+        gboolean value_bool = FALSE;
+        gchar *xpath = NULL;
         int j;
 
         /* We are guaranteed to have at least the default "C" locale and we
          * want to ignore that, hence the NULL check on index 'j + 1'.
          */
-        for (j = 0; langs[j + 1] != NULL; j++) {
-            xpath = g_strdup_printf("string(./%s[lang('%s')])", keys[i], langs[j]);
-            value = osinfo_loader_string(xpath, ctxt, err);
-            g_free(xpath);
-            if (error_is_set(err))
-                return;
+        if (keys[i].type == G_TYPE_STRING) {
+            for (j = 0; langs[j + 1] != NULL; j++) {
+                xpath = g_strdup_printf("string(./%s[lang('%s')])",
+                                        keys[i].name, langs[j]);
+                value_str = osinfo_loader_string(xpath, ctxt, err);
+                g_free(xpath);
+                xpath = NULL;
+                if (error_is_set(err))
+                    return;
 
-            if (value != NULL)
+                if (value_str != NULL)
+                    break;
+            }
+        }
+
+        switch (keys[i].type) {
+            case G_TYPE_STRING:
+                xpath = g_strdup_printf("string(./%s)", keys[i].name);
+                if (value_str == NULL) {
+                    value_str = osinfo_loader_string(xpath, ctxt, err);
+                }
+                break;
+            case G_TYPE_BOOLEAN:
+                xpath = g_strdup_printf("./%s", keys[i].name);
+                value_bool = osinfo_loader_boolean(xpath, ctxt, err);
+                break;
+            default:
+                g_warn_if_reached();
                 break;
         }
+        g_free(xpath);
 
-        if (value == NULL) {
-            xpath = g_strdup_printf("string(./%s)", keys[i]);
-            value = osinfo_loader_string(xpath, ctxt, err);
-            g_free(xpath);
-            if (error_is_set(err))
-                return;
-        }
-
-        if (value) {
-            osinfo_entity_set_param(entity, keys[i], value);
-            g_free(value);
+        switch (keys[i].type) {
+            case G_TYPE_STRING:
+                if (value_str) {
+                    osinfo_entity_set_param(entity, keys[i].name, value_str);
+                    g_free(value_str);
+                    value_str = NULL;
+                }
+                break;
+            case G_TYPE_BOOLEAN:
+                osinfo_entity_set_param_boolean(entity, keys[i].name, value_bool);
+                break;
+            default:
+                g_warn_if_reached();
+                break;
         }
+        g_warn_if_fail(value_str == NULL);
     }
 
     /* Then any site specific custom keys. x-... Can be repeated */
@@ -352,16 +427,16 @@ static void osinfo_loader_device(OsinfoLoader *loader,
                                  GError **err)
 {
     gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
-    const gchar *const keys[] = {
-        OSINFO_DEVICE_PROP_VENDOR,
-        OSINFO_DEVICE_PROP_VENDOR_ID,
-        OSINFO_DEVICE_PROP_PRODUCT,
-        OSINFO_DEVICE_PROP_PRODUCT_ID,
-        OSINFO_DEVICE_PROP_SUBSYSTEM,
-        OSINFO_DEVICE_PROP_BUS_TYPE,
-        OSINFO_DEVICE_PROP_CLASS,
-        OSINFO_DEVICE_PROP_NAME,
-        NULL,
+    const OsinfoEntityKey keys[] = {
+        { OSINFO_DEVICE_PROP_VENDOR, G_TYPE_STRING },
+        { OSINFO_DEVICE_PROP_VENDOR_ID, G_TYPE_STRING },
+        { OSINFO_DEVICE_PROP_PRODUCT, G_TYPE_STRING },
+        { OSINFO_DEVICE_PROP_PRODUCT_ID, G_TYPE_STRING },
+        { OSINFO_DEVICE_PROP_SUBSYSTEM, G_TYPE_STRING },
+        { OSINFO_DEVICE_PROP_BUS_TYPE, G_TYPE_STRING },
+        { OSINFO_DEVICE_PROP_CLASS, G_TYPE_STRING },
+        { OSINFO_DEVICE_PROP_NAME, G_TYPE_STRING },
+        { NULL, G_TYPE_INVALID }
     };
     if (!id) {
         OSINFO_ERROR(err, _("Missing device id property"));
@@ -388,9 +463,9 @@ static void osinfo_loader_device_link(OsinfoLoader *loader,
         return;
 
     for (i = 0 ; i < nrelated ; i++) {
-        const gchar *keys[] = {
-            OSINFO_DEVICELINK_PROP_DRIVER,
-            NULL,
+        const OsinfoEntityKey keys[] = {
+            { OSINFO_DEVICELINK_PROP_DRIVER, G_TYPE_STRING },
+            { NULL, G_TYPE_INVALID }
         };
         gchar *id = (gchar *)xmlGetProp(related[i], BAD_CAST "id");
         if (!id) {
@@ -461,16 +536,16 @@ static void osinfo_loader_product(OsinfoLoader *loader,
                                   xmlNodePtr root,
                                   GError **err)
 {
-    const gchar *const keys[] = {
-        OSINFO_PRODUCT_PROP_NAME,
-        OSINFO_PRODUCT_PROP_VENDOR,
-        OSINFO_PRODUCT_PROP_VERSION,
-        OSINFO_PRODUCT_PROP_LOGO,
-        OSINFO_PRODUCT_PROP_SHORT_ID,
-        OSINFO_PRODUCT_PROP_RELEASE_DATE,
-        OSINFO_PRODUCT_PROP_EOL_DATE,
-        OSINFO_PRODUCT_PROP_CODENAME,
-        NULL,
+    const OsinfoEntityKey keys[] = {
+        { OSINFO_PRODUCT_PROP_NAME, G_TYPE_STRING },
+        { OSINFO_PRODUCT_PROP_VENDOR, G_TYPE_STRING },
+        { OSINFO_PRODUCT_PROP_VERSION, G_TYPE_STRING },
+        { OSINFO_PRODUCT_PROP_LOGO, G_TYPE_STRING },
+        { OSINFO_PRODUCT_PROP_SHORT_ID, G_TYPE_STRING },
+        { OSINFO_PRODUCT_PROP_RELEASE_DATE, G_TYPE_STRING },
+        { OSINFO_PRODUCT_PROP_EOL_DATE, G_TYPE_STRING },
+        { OSINFO_PRODUCT_PROP_CODENAME, G_TYPE_STRING },
+        { NULL, G_TYPE_INVALID }
     };
 
     osinfo_loader_entity(loader, OSINFO_ENTITY(product), keys, ctxt, root, err);
@@ -509,9 +584,6 @@ static void osinfo_loader_platform(OsinfoLoader *loader,
                                    GError **err)
 {
     gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
-    const gchar *const keys[] = {
-        NULL,
-    };
     if (!id) {
         OSINFO_ERROR(err, _("Missing platform id property"));
         return;
@@ -520,7 +592,7 @@ static void osinfo_loader_platform(OsinfoLoader *loader,
     OsinfoPlatform *platform = osinfo_loader_get_platform(loader, id);
     xmlFree(id);
 
-    osinfo_loader_entity(loader, OSINFO_ENTITY(platform), keys, ctxt, root, err);
+    osinfo_loader_entity(loader, OSINFO_ENTITY(platform), NULL, ctxt, root, err);
     if (error_is_set(err))
         return;
 
@@ -540,9 +612,6 @@ static void osinfo_loader_deployment(OsinfoLoader *loader,
                                      GError **err)
 {
     gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
-    const gchar *const keys[] = {
-        NULL
-    };
     if (!id) {
         OSINFO_ERROR(err, _("Missing deployment id property"));
         return;
@@ -569,7 +638,7 @@ static void osinfo_loader_deployment(OsinfoLoader *loader,
     OsinfoDeployment *deployment = osinfo_deployment_new(id, os, platform);
     xmlFree(id);
 
-    osinfo_loader_entity(loader, OSINFO_ENTITY(deployment), keys, ctxt, root, err);
+    osinfo_loader_entity(loader, OSINFO_ENTITY(deployment), NULL, ctxt, root, err);
     if (error_is_set(err)) {
         g_object_unref(G_OBJECT(deployment));
         return;
@@ -669,12 +738,12 @@ static OsinfoAvatarFormat *osinfo_loader_avatar_format(OsinfoLoader *loader,
                                                        GError **err)
 {
     OsinfoAvatarFormat *avatar_format;
-    const gchar *const keys[] = {
-        OSINFO_AVATAR_FORMAT_PROP_MIME_TYPE,
-        OSINFO_AVATAR_FORMAT_PROP_WIDTH,
-        OSINFO_AVATAR_FORMAT_PROP_HEIGHT,
-        OSINFO_AVATAR_FORMAT_PROP_ALPHA,
-        NULL
+    const OsinfoEntityKey keys[] = {
+        { OSINFO_AVATAR_FORMAT_PROP_MIME_TYPE, G_TYPE_STRING },
+        { OSINFO_AVATAR_FORMAT_PROP_WIDTH, G_TYPE_STRING },
+        { OSINFO_AVATAR_FORMAT_PROP_HEIGHT, G_TYPE_STRING },
+        { OSINFO_AVATAR_FORMAT_PROP_ALPHA, G_TYPE_BOOLEAN },
+        { NULL, G_TYPE_INVALID }
     };
 
     avatar_format = osinfo_avatar_format_new();
@@ -695,16 +764,16 @@ static void osinfo_loader_install_script(OsinfoLoader *loader,
                                          GError **err)
 {
     gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
-    const gchar *const keys[] = {
-        OSINFO_INSTALL_SCRIPT_PROP_PROFILE,
-        OSINFO_INSTALL_SCRIPT_PROP_PRODUCT_KEY_FORMAT,
-        OSINFO_INSTALL_SCRIPT_PROP_PATH_FORMAT,
-        OSINFO_INSTALL_SCRIPT_PROP_EXPECTED_FILENAME,
-        OSINFO_INSTALL_SCRIPT_PROP_CAN_PRE_INSTALL_DRIVERS,
-        OSINFO_INSTALL_SCRIPT_PROP_CAN_POST_INSTALL_DRIVERS,
-        OSINFO_INSTALL_SCRIPT_PROP_PRE_INSTALL_DRIVERS_SIGNING_REQ,
-        OSINFO_INSTALL_SCRIPT_PROP_POST_INSTALL_DRIVERS_SIGNING_REQ,
-        NULL
+    const OsinfoEntityKey keys[] = {
+        { OSINFO_INSTALL_SCRIPT_PROP_PROFILE, G_TYPE_STRING },
+        { OSINFO_INSTALL_SCRIPT_PROP_PRODUCT_KEY_FORMAT, G_TYPE_STRING },
+        { OSINFO_INSTALL_SCRIPT_PROP_PATH_FORMAT, G_TYPE_STRING },
+        { OSINFO_INSTALL_SCRIPT_PROP_EXPECTED_FILENAME, G_TYPE_STRING },
+        { OSINFO_INSTALL_SCRIPT_PROP_CAN_PRE_INSTALL_DRIVERS, G_TYPE_BOOLEAN },
+        { OSINFO_INSTALL_SCRIPT_PROP_CAN_POST_INSTALL_DRIVERS, G_TYPE_BOOLEAN },
+        { OSINFO_INSTALL_SCRIPT_PROP_PRE_INSTALL_DRIVERS_SIGNING_REQ, G_TYPE_STRING },
+        { OSINFO_INSTALL_SCRIPT_PROP_POST_INSTALL_DRIVERS_SIGNING_REQ, G_TYPE_STRING },
+        { NULL, G_TYPE_INVALID }
     };
     gchar *value = NULL;
     xmlNodePtr *nodes = NULL;
@@ -790,11 +859,11 @@ static OsinfoMedia *osinfo_loader_media (OsinfoLoader *loader,
     xmlChar *installer = xmlGetProp(root, BAD_CAST OSINFO_MEDIA_PROP_INSTALLER);
     xmlChar *installer_reboots =
             xmlGetProp(root, BAD_CAST OSINFO_MEDIA_PROP_INSTALLER_REBOOTS);
-    const gchar *const keys[] = {
-        OSINFO_MEDIA_PROP_URL,
-        OSINFO_MEDIA_PROP_KERNEL,
-        OSINFO_MEDIA_PROP_INITRD,
-        NULL
+    const OsinfoEntityKey keys[] = {
+        { OSINFO_MEDIA_PROP_URL, G_TYPE_STRING },
+        { OSINFO_MEDIA_PROP_KERNEL, G_TYPE_STRING },
+        { OSINFO_MEDIA_PROP_INITRD, G_TYPE_STRING },
+        { NULL, G_TYPE_INVALID }
     };
 
     OsinfoMedia *media = osinfo_media_new(id, arch);
@@ -822,7 +891,22 @@ static OsinfoMedia *osinfo_loader_media (OsinfoLoader *loader,
         xmlFree(installer_reboots);
     }
 
-    gint nnodes = osinfo_loader_nodeset("./iso/*", ctxt, &nodes, err);
+    gint nnodes = osinfo_loader_nodeset("./variant", ctxt, &nodes, err);
+    if (error_is_set(err)) {
+        g_object_unref(media);
+        return NULL;
+    }
+
+    for (i = 0 ; i < nnodes ; i++) {
+        gchar *variant_id = (gchar *)xmlGetProp(nodes[i], BAD_CAST "id");
+        osinfo_entity_add_param(OSINFO_ENTITY(media),
+                                OSINFO_MEDIA_PROP_VARIANT,
+                                variant_id);
+        xmlFree(variant_id);
+    }
+    g_free(nodes);
+
+    nnodes = osinfo_loader_nodeset("./iso/*", ctxt, &nodes, err);
     if (error_is_set(err)) {
         g_object_unref(media);
         return NULL;
@@ -885,12 +969,12 @@ static OsinfoTree *osinfo_loader_tree (OsinfoLoader *loader,
     guint i;
 
     gchar *arch = (gchar *)xmlGetProp(root, BAD_CAST "arch");
-    const gchar *const keys[] = {
-        OSINFO_TREE_PROP_URL,
-        OSINFO_TREE_PROP_KERNEL,
-        OSINFO_TREE_PROP_INITRD,
-        OSINFO_TREE_PROP_BOOT_ISO,
-        NULL
+    const OsinfoEntityKey keys[] = {
+        { OSINFO_TREE_PROP_URL, G_TYPE_STRING },
+        { OSINFO_TREE_PROP_KERNEL, G_TYPE_STRING },
+        { OSINFO_TREE_PROP_INITRD, G_TYPE_STRING },
+        { OSINFO_TREE_PROP_BOOT_ISO, G_TYPE_STRING },
+        { NULL, G_TYPE_INVALID }
     };
 
     OsinfoTree *tree = osinfo_tree_new(id, arch);
@@ -936,6 +1020,25 @@ static OsinfoTree *osinfo_loader_tree (OsinfoLoader *loader,
     return tree;
 }
 
+static OsinfoOsVariant *osinfo_loader_os_variant (OsinfoLoader *loader,
+                                                  xmlXPathContextPtr ctxt,
+                                                  xmlNodePtr root,
+                                                  GError **err)
+{
+    const OsinfoEntityKey keys[] = {
+        { OSINFO_OS_VARIANT_PROP_NAME, G_TYPE_STRING },
+        { NULL, G_TYPE_INVALID }
+    };
+
+    gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
+    OsinfoOsVariant *variant= osinfo_os_variant_new(id);
+    xmlFree(id);
+
+    osinfo_loader_entity(loader, OSINFO_ENTITY(variant), keys, ctxt, root, err);
+
+    return variant;
+}
+
 static OsinfoResources *osinfo_loader_resources(OsinfoLoader *loader,
                                                 xmlXPathContextPtr ctxt,
                                                 xmlNodePtr root,
@@ -1094,11 +1197,13 @@ static void osinfo_loader_os(OsinfoLoader *loader,
     int nnodes;
 
     gchar *id = (gchar *)xmlGetProp(root, BAD_CAST "id");
-    const gchar *const keys[] = {
-        OSINFO_OS_PROP_FAMILY,
-        OSINFO_OS_PROP_DISTRO,
-        NULL
+    const OsinfoEntityKey keys[] = {
+        { OSINFO_OS_PROP_FAMILY, G_TYPE_STRING },
+        { OSINFO_OS_PROP_DISTRO, G_TYPE_STRING },
+        { OSINFO_OS_PROP_RELEASE_STATUS, G_TYPE_STRING },
+        { NULL, G_TYPE_INVALID }
     };
+
     if (!id) {
         OSINFO_ERROR(err, _("Missing os id property"));
         return;
@@ -1159,6 +1264,27 @@ static void osinfo_loader_os(OsinfoLoader *loader,
 
     g_free(nodes);
 
+    nnodes = osinfo_loader_nodeset("./variant", ctxt, &nodes, err);
+    if (error_is_set(err))
+        goto cleanup;
+
+    for (i = 0 ; i < nnodes ; i++) {
+        xmlNodePtr saved = ctxt->node;
+        ctxt->node = nodes[i];
+        OsinfoOsVariant *variant = osinfo_loader_os_variant(loader,
+                                                            ctxt,
+                                                            nodes[i],
+                                                            err);
+        ctxt->node = saved;
+        if (error_is_set(err))
+            goto cleanup;
+
+        osinfo_os_add_variant (os, variant);
+        g_object_unref(G_OBJECT(variant));
+    }
+
+    g_free(nodes);
+
     nnodes = osinfo_loader_nodeset("./resources", ctxt, &nodes, err);
     if (error_is_set(err))
         goto cleanup;
