@@ -52,6 +52,7 @@ struct _OsinfoOsPrivate
 
     OsinfoMediaList *medias;
     OsinfoTreeList *trees;
+    OsinfoOsVariantList *variants;
     OsinfoResourcesList *minimum;
     OsinfoResourcesList *recommended;
 
@@ -115,6 +116,7 @@ osinfo_os_finalize (GObject *object)
     g_list_free(os->priv->deviceLinks);
     g_object_unref(os->priv->medias);
     g_object_unref(os->priv->trees);
+    g_object_unref(os->priv->variants);
 
     g_object_unref(os->priv->scripts);
 
@@ -177,6 +179,7 @@ osinfo_os_init (OsinfoOs *os)
     os->priv->deviceLinks = NULL;
     os->priv->medias = osinfo_medialist_new ();
     os->priv->trees = osinfo_treelist_new ();
+    os->priv->variants = osinfo_os_variantlist_new ();
     os->priv->minimum = osinfo_resourceslist_new ();
     os->priv->recommended = osinfo_resourceslist_new ();
     os->priv->scripts = osinfo_install_scriptlist_new ();
@@ -401,6 +404,25 @@ const gchar *osinfo_os_get_distro(OsinfoOs *os)
     return osinfo_entity_get_param_value(OSINFO_ENTITY(os), "distro");
 }
 
+/**
+ * osinfo_os_get_release_status:
+ * @os: an #OsinfoOs
+ *
+ * Use this to determine the release status of the @os.
+ *
+ * Returns: (type OsinfoReleaseStatus): release status of @os.
+ */
+int osinfo_os_get_release_status(OsinfoOs *os)
+{
+    g_return_val_if_fail(OSINFO_IS_OS(os), OSINFO_RELEASE_STATUS_RELEASED);
+
+    return osinfo_entity_get_param_value_enum
+        (OSINFO_ENTITY(os),
+         OSINFO_OS_PROP_RELEASE_STATUS,
+         OSINFO_TYPE_RELEASE_STATUS,
+         OSINFO_RELEASE_STATUS_RELEASED);
+}
+
 /**
  * osinfo_os_get_media_list:
  * @os: an operating system
@@ -470,6 +492,40 @@ void osinfo_os_add_tree(OsinfoOs *os, OsinfoTree *tree)
     osinfo_list_add(OSINFO_LIST(os->priv->trees), OSINFO_ENTITY(tree));
 }
 
+/**
+ * osinfo_os_get_variant_list:
+ * @os: an operating system
+ *
+ * Gets all known variants of operating system @os.
+ *
+ * Returns: (transfer full): A list of variants
+ */
+OsinfoOsVariantList *osinfo_os_get_variant_list(OsinfoOs *os)
+{
+    g_return_val_if_fail(OSINFO_IS_OS(os), NULL);
+
+    OsinfoOsVariantList *newList = osinfo_os_variantlist_new();
+
+    osinfo_list_add_all(OSINFO_LIST(newList), OSINFO_LIST(os->priv->variants));
+
+    return newList;
+}
+
+/**
+ * osinfo_os_add_variant:
+ * @os: an operating system
+ * @variant: (transfer none): the variant to add
+ *
+ * Adds a variant @variant to operating system @os.
+ */
+void osinfo_os_add_variant(OsinfoOs *os, OsinfoOsVariant *variant)
+{
+    g_return_if_fail(OSINFO_IS_OS(os));
+    g_return_if_fail(OSINFO_IS_OS_VARIANT(variant));
+
+    osinfo_list_add(OSINFO_LIST(os->priv->variants), OSINFO_ENTITY(variant));
+}
+
 /**
  * osinfo_os_get_minimum_resources:
  * @os: an operating system
