@@ -277,7 +277,9 @@ int main(void)
     Suite *s = list_suite ();
     SRunner *sr = srunner_create (s);
 
+#if !GLIB_CHECK_VERSION(2,35,1)
     g_type_init();
+#endif
 
     /* Upfront so we don't confuse valgrind */
     osinfo_entity_get_type();
