@@ -131,7 +131,9 @@ int main(void)
     Suite *s = platform_suite ();
     SRunner *sr = srunner_create (s);
 
+#if !GLIB_CHECK_VERSION(2,35,1)
     g_type_init();
+#endif
 
     /* Upfront so we don't confuse valgrind */
     osinfo_platform_get_type();
