@@ -256,7 +256,9 @@ gint main(gint argc, gchar **argv)
     bindtextdomain(GETTEXT_PACKAGE, LOCALEDIR);
     bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
+#if !GLIB_CHECK_VERSION(2,35,1)
     g_type_init();
+#endif
 
     context = g_option_context_new(_("- Validate XML documents "));
 
